#
# spec file for package python-pyxb
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define realnam PyXB
%{?!python_module:%define python_module() python3-%{**}}
%define oldpython python
Name:           python3-pyxb
Version:        1.2.6
Release:        150400.5.69
Summary:        Python class code generator based on XMLSchemas
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/pabigot/pyxb
Source0:        https://files.pythonhosted.org/packages/source/P/%{realnam}/%{realnam}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM eight-args-datetime.patch gh#pabigot/pyxb#123 mcepl@suse.com
# fix arguments for the time fields
Patch0:         eight-args-datetime.patch
# PATCH-FIX-UPSTREAM deprecated-collection-use.patch gh#pabigot/pyxb#111 mcepl@suse.com
# Use collections.abc
Patch1:         deprecated-collection-use.patch
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module xml}
BuildArch:      noarch
Requires:       python3-xml
Requires(post):   update-alternatives
Requires(postun):  update-alternatives
Obsoletes:      %{oldpython}-pyxb < %{version}-%{release}
%python_subpackages

%description
PyXB is a pure Python package that generates Python code for classes that correspond to data structures defined by XMLSchema.
In concept it is similar to JAXB for Java and CodeSynthesis XSD for C++.

%prep
%autosetup -p1 -n %{realnam}-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pyxbdump
%python_clone -a %{buildroot}%{_bindir}/pyxbgen
%python_clone -a %{buildroot}%{_bindir}/pyxbwsdl
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# It is hard to rewrite tests to the standard form
# also, gh#pabigot/pyxb#133
%python_exec setup.py test -v

%post
%python_install_alternative pyxbdump
%python_install_alternative pyxbgen
%python_install_alternative pyxbwsdl

%postun
%python_uninstall_alternative pyxbdump
%python_uninstall_alternative pyxbgen
%python_uninstall_alternative pyxbwsdl

%files %{python_files}
%license LICENSE
%doc NOTICE PKG-INFO README.txt
%{python_sitelib}/pyxb/
%{python_sitelib}/PyXB-%{version}-*.egg-info
%python_alternative %{_bindir}/pyxbdump
%python_alternative %{_bindir}/pyxbgen
%python_alternative %{_bindir}/pyxbwsdl

%changelog
* Mon Nov 15 2021 mcepl@suse.com
- Obsolete old python2 packages in SLE as well.
* Mon Oct 25 2021 mcepl@suse.com
- Update to 1.2.6:
  - Overriding the DOM implementation via PYXB_XML_STYLE is
    deprecated. See issue 87.
  - Examples were not in the test suite. issue 61
  - Disallow setting an empty namespace prefix. issue 66
  - Support unicode identifiers under Python 3. issue 67
  - Do not use default value when constructing empty scalar
    values. issue 71
  - Defer validation when type is not yet available. issue 72
  - Correct validation of fixed values from XML. issue 73
  - Remove GPL code from PyXB. issue 77
  - Fix identification of restricted complex type. issue 78
  - Discard schema elements that cannot produce content. issue 79
  - Demonstrate use of overriding built-in bindings so XHTML
    model groups can be referenced. issue 81
  - Deconflict class properties from module identifiers. issue 27
  - Correct handling of xsi:type on non-abstract types. issue 32
  - Fix generation of zero-span durations. issue 38
  - Document how to use file URIs on Windows. issue 34
  - Document need for common bindings when generating OpenGIS
    bindings. issue 28
  - Fix literal representation of not-a-number and infinite
    values. issue 43
  - Document that Python 3 is supported. issue 36
  - Fix processing of empty binary data tpyes. issue 51
  - Fix transition sort key to support Python 3. issue 52
  - Fix generation of modules that cannot be imported due to use
    of invalid characters in the module path. issue 48
  - Add a method to xsd.base64Binary to allow a heavy-weight
    validation step to be bypassed. issue 50
- Clean up and make tests passing, more or less.
- Add patches for that purpose:
  - deprecated-collection-use.patch
  - eight-args-datetime.patch
* Tue Mar 17 2015 tchvatal@suse.com
- Fix build on sle11 as it is needed for java-packages
* Sat Jan 24 2015 p.drouand@gmail.com
- Remove python direct dependency; let RPM handle it
* Sat Jan 24 2015 mailaender@opensuse.org
- update to version 1.2.4
* Fri Jun 13 2014 tchvatal@suse.com
- update to version 1.2.3
* Tue Apr  5 2011 tzotsos@opensuse.org
- initial OBS build
